Returns the distance between two compositional vectors using the chi-square distance.
chisq.dist(x.1, x.2, gamma)compositional vector
compositional vector
power transform taken to be 1.
Stewart, C., Iverson, S. and Field, C. (2014) Testing for a change in diet using fatty acid signatures. Environmental and Ecological Statistics 21, pp. 775-792.
Connie Stewart (2017) An approach to measure distance between compositional diet estimates containing essential zeros, Journal of Applied Statistics, 44:7, 1137-1152, DOI: 10.1080/02664763.2016.1193846