Learn R Programming

QFASA (version 1.2.1)

prey.on.prey: Each prey fatty acid signature is systematically removed from the supplied prey database and its QFASA diet estimate is obtained by treating the individual as a predator.

Description

Each prey fatty acid signature is systematically removed from the supplied prey database and its QFASA diet estimate is obtained by treating the individual as a predator.

Usage

prey.on.prey(preybase, dist.meas, gamma = 1)

Value

diet estimate

Arguments

preybase

first column is name of species and remaining columns are fatty acids.

dist.meas

see help file for p.QFASA.

gamma

see help file for p.QFASA.

Examples

Run this code
data(preyFAs)
my.preybase <- preyFAs[, -c(1,3)]

# Note: uncomment examples to run. CRAN tests fail because execution time > 5 seconds
# diets.out <- prey.on.prey(my.preybase, 2)
# round(MEANmeth(diets.out), 3)
     

Run the code above in your browser using DataLab